// this is a very basic template. use it to start writing your own effects.
// if you want effects with lighting start from one of the GouraudXXXX or PhongXXXX effects

// --------------------------------------------------------------------------------------------------
// PARAMETERS:
// --------------------------------------------------------------------------------------------------

// -------------------------------------------------------------------------
// PARAMETERS:
// -------------------------------------------------------------------------

//transforms
float4x4 tW: WORLD; //the models world matrix
float4x4 tV: VIEW; //view matrix as set via Renderer (DX9)
float4x4 tP: PROJECTION; //projection matrix as set via Renderer (DX9)
float4x4 tWVP: WORLDVIEWPROJECTION;

//texture1
texture Tex <string uiname="Left";>;
sampler Samp = sampler_state //sampler for doing the texture-lookup
{
   Texture   = (Tex);          //apply a texture to the sampler
   MipFilter = LINEAR;         //sampler states
   MinFilter = LINEAR;
   MagFilter = LINEAR;
};


//texture2
texture Tex2 <string uiname="Right";>;
sampler Samp2 = sampler_state //sampler for doing the texture-lookup
{
   Texture   = (Tex2);         //apply a texture to the sampler
   MipFilter = LINEAR;         //sampler states
   MinFilter = LINEAR;
   MagFilter = LINEAR;
};

//texture transformation marked with semantic TEXTUREMATRIX to achieve symmetric transformations
float4x4 tTex: TEXTUREMATRIX <string uiname="Texture Transform";>;

//creates a color pin with the default value black with alphachanel set to 1
//and with pinname "Color for Hello"

int on_  <string uiname="On";> = 1;

//the data structure: "vertexshader to pixelshader"
//used as output data with the VS function
//and as input data with the PS function
struct vs2ps
{
   float4 Pos : POSITION;
   float4 TexCd : TEXCOORD0;
};
// -------------------------------------------------------------------------
// VERTEXSHADERS
// -------------------------------------------------------------------------

vs2ps VS(
   float4 Pos : POSITION,
   float4 TexCd : TEXCOORD0)
{
   //inititalize all fields of output struct with 0
   vs2ps Out = (vs2ps)0;

   //transform position
   Out.Pos = mul(Pos, tWVP);

   //transform texturecoordinates
   Out.TexCd = mul(TexCd, tTex);

   return Out;
}

// -------------------------------------------------------------------------
// PIXELSHADERS:
// -------------------------------------------------------------------------


float4 Pseudocolor(vs2ps In): COLOR
{
   //texture lookup to access the pixels of the texture
   float4 col = tex2D(Samp2, In.TexCd);//float2(In.TexCd.x+(2.0/320.0),In.TexCd.y));
   float4 col2 = tex2D(Samp, In.TexCd);
   //if the pixels are white then overwrite them with HelloColor (above input color)
   //or do nothing
   //then return col

   if (on_==1)
   {
      col.r = col.r;
      col.g = col2.g;
      col.b = col2.b;
   }
   return col;
}

float4 Blue(vs2ps In): COLOR
{
   //texture lookup to access the pixels of the texture
   float4 col = tex2D(Samp2, In.TexCd);//float2(In.TexCd.x+(2.0/320.0),In.TexCd.y));
   float4 col2 = tex2D(Samp, In.TexCd);
   //if the pixels are white then overwrite them with HelloColor (above input color)
   //or do nothing
   //then return col

   if (on_==1)
   {
      col.r = col.r;
      col.g = 0;
      col.b = col2.b;
   }
   return col;
}


float4 Green(vs2ps In): COLOR
{
   //texture lookup to access the pixels of the texture
   float4 col = tex2D(Samp2, In.TexCd);//float2(In.TexCd.x+(2.0/320.0),In.TexCd.y));
   float4 col2 = tex2D(Samp, In.TexCd);
   //if the pixels are white then overwrite them with HelloColor (above input color)
   //or do nothing
   //then return col

   if (on_==1)
   {
      col.r = col.r;
      col.g = col2.g;
      col.b = 0;
   }
   return col;
}



// -------------------------------------------------------------------------
// TECHNIQUES:
// -------------------------------------------------------------------------

technique Pseudocolor
{
   pass P0
   {
       VertexShader = compile vs_1_1 VS();
       PixelShader  = compile ps_2_0 Pseudocolor();
   }
}

technique Blue 
{
   pass P0
   {
       VertexShader = compile vs_1_1 VS();
       PixelShader  = compile ps_2_0 Blue();
   }
}

technique Green
{
   pass P0
   {
       VertexShader = compile vs_1_1 VS();
       PixelShader  = compile ps_2_0 Green();
   }
}
